<div align=center>
  
  # IPweather v0.1.2
  
  **A python package to get the Ip of the user and current weather with a IP**
</div>

## +example:
![image](https://user-images.githubusercontent.com/81589649/175363389-1b83aed4-5634-409a-b587-5cfcbdd213d1.png)

## +Install:
**manually**
- Download project
- cd in the project dir with the console
- run: `pip install . --upgrade`
- your done!

**install with pip**
- run: `pip install IPweather`
- your done!


### author:
@cookie0o on github
